==> haskell-blaze-markup-0.7.0.3-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-blaze-markup/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-markup
version: 0.7.0.3
id: blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
key: blaze_C7imNkL0ufD2cjmU64FP9k
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier, Deepak Jois
exposed: True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-markup-0.7.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-markup-0.7.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/blaze-markup-0.7.0.3
hs-libraries: HSblaze-markup-0.7.0.3-C7imNkL0ufD2cjmU64FP9k
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock
haddock-html: /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-markup-0.7.0.3-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-blaze-markup/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-markup
version: 0.7.0.3
id: blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
key: blaze_JGtgJgx8yqB3DdKuU3sbgD
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier, Deepak Jois
exposed: True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-markup-0.7.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-markup-0.7.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/blaze-markup-0.7.0.3
hs-libraries: HSblaze-markup-0.7.0.3-JGtgJgx8yqB3DdKuU3sbgD
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock
haddock-html: /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
